@@ -31,16 +31,20 @@ def jsonify(structure):
     return JSONLeveledListEncoder().encode(structure)
 
 
+def get_description(mod):
+    distribution = pkg_resources.get_distribution(mod)
+    if distribution.has_metadata('PKG-INFO'):
+        meta = distribution.get_metadata('PKG-INFO')
+    elif distribution.has_metadata('METADATA'):
+        meta = distribution.get_metadata('METADATA')
+    else:
+        return None
+    return email.message_from_string(meta).get('Summary', None)
+
+
 class TreeifyPlugin(Plugin):
     name = 'Treeify'
-    description = (
-        email.message_from_string(
-            pkg_resources
-            .get_distribution('lektor_treeify')
-            .get_metadata('PKG-INFO')
-        )
-        .get('Summary', None)
-    )
+    description = get_description(__module__)
 
     def on_setup_env(self, **extra):
         self.env.jinja_env.filters['treeify'] = treeify
